<%inherit file="master.html"/> <%def name="counts_box(r, status)">
${release_updates_counts[r['name']][status+'_updates_total']}
<%def name="release_list(release_status, stable_only=False)">

- ${release_status.capitalize()} Releases ${len(request.releases[release_status])}
  % if not stable_only:
  Pending
  Testing
  % endif
  Stable
% for r in request.releases[release_status]:
- ${r['long_name']}
  % if not stable_only: ${counts_box(r, "pending")} ${counts_box(r, "testing")} % endif ${counts_box(r, "stable")}
% endfor

### Releases

${release_list('current', stable_only=False)} ${release_list('pending', stable_only=False)} ${release_list('archived', stable_only=True)}